@@ -1,7 +1,7 @@
 from .classdomain import ClassDomain, Label
 from .samples import DataSample
 from .struct import Field, Struct
-from .utils import Util
+from .utils import Util, OptionEatAll, prepare_input
 
 __all__ = [
     "ClassDomain",
@@ -10,4 +10,6 @@ __all__ = [
     "Field",
     "Struct",
     "Util",
+    "OptionEatAll",
+    "prepare_input",
 ]
