@@ -122,6 +122,6 @@ class DetectionParse(BaseParse):
             sample_struct.add_field(annotation_field)  # 添加annotation field
             if annotation_option_flag:
                 sample_struct.set_optional("annotations")
-            return (sample_struct,), [self._class_domain, self._class_domain.parent_domain], sample_container
+            return (object_struct, sample_struct), [self._class_domain, self._class_domain.parent_domain], sample_container
         else:
-            return (object_struct, sample_struct), [], sample_container
+            return (sample_struct), [], sample_container
